@@ -254,6 +254,7 @@ megaGroups = {
             "webvr",
             "wecg",
             "wicg",
+            "wintercg",
         ]
     ),
     "whatwg": frozenset(["whatwg"]),
@@ -299,6 +300,7 @@ w3cCgs = frozenset(
         "web-bluetooth-cg",
         "wecg",
         "wicg",
+        "wintercg",
     ]
 )
 assert w3cCgs.issubset(megaGroups["w3c"])
@@ -339,12 +341,12 @@ def canonicalizeStatus(rawStatus, group):
 
     def megaGroupsForStatus(status):
         # Returns a list of megagroups that recognize the given status
-        megaGroups = []
+        mgs = []
         for key in shortToLongStatus:
             mg, _, s = key.partition("/")
             if s == status:
-                megaGroups.append(mg)
-        return megaGroups
+                mgs.append(mg)
+        return mgs
 
     # Canonicalize the rawStatus that was passed in, into a known form.
     # Might be foo/BAR, or just BAR.
