@@ -5,7 +5,7 @@ from collections import Counter, defaultdict, namedtuple
 from urllib import parse
 from PIL import Image
 
-from . import biblio, config, dfnpanels, h, func, t, messages as m
+from . import biblio, config, dfnpanels, h, func, t, messages as m, idl
 
 
 class MarkdownCodeSpans(func.Functor):
@@ -70,16 +70,12 @@ class MarkdownCodeSpans(func.Functor):
                     # Markdown code span, so massage per CommonMark rules.
                     import string
 
-                    t = h.escapeHTML(repl[1]).strip(string.whitespace)
-                    t = re.sub("[" + string.whitespace + "]{2,}", " ", t)
-                    return "{2}<code data-opaque bs-autolink-syntax='{1}'>{0}</code>".format(
-                        t, h.escapeAttr(repl[2]), repl[0]
-                    )
-                return "<code data-opaque data-span-tag={0} bs-autolink-syntax='{2}'>{1}</code>".format(
-                    repl[0], h.escapeHTML(repl[1]), h.escapeAttr(repl[2])
-                )
+                    text = h.escapeHTML(repl[1]).strip(string.whitespace)
+                    text = re.sub("[" + string.whitespace + "]{2,}", " ", text)
+                    return f"{repl[0]}<code data-opaque bs-autolink-syntax='{h.escapeAttr(repl[2])}'>{text}</code>"
+                return f"<code data-opaque data-span-tag={repl[0]} bs-autolink-syntax='{h.escapeAttr(repl[2])}'>{h.escapeHTML(repl[1])}</code>"
 
-            return re.sub("\ue0ff", codeSpanReviver, self.__val__)
+            return re.sub(r"\ue0ff", codeSpanReviver, self.__val__)
         return self.__val__
 
 
@@ -143,7 +139,7 @@ def canonicalizeShortcuts(doc: "t.SpecType"):
     for el in h.findAll(",".join(f"[{attr}]" for attr in attrFixup), doc):
         for attr, fixedAttr in attrFixup.items():
             if el.get(attr) is not None:
-                el.set(fixedAttr, el.get(attr))
+                el.set(fixedAttr, t.cast(str, el.get(attr)))
                 del el.attrib[attr]
 
     # The next two aren't in the above dict because some of the words conflict with existing attributes on some elements.
@@ -163,11 +159,12 @@ def canonicalizeShortcuts(doc: "t.SpecType"):
     for el in h.findAll(config.dfnElementsSelector + ", a", doc):
         if el.get("for") is None:
             continue
-        if el.tag == "a":
-            el.set("data-link-for", el.get("for"))
-        else:
-            el.set("data-dfn-for", el.get("for"))
+        _for = t.cast(str, el.get("for"))
         del el.attrib["for"]
+        if el.tag == "a":
+            el.set("data-link-for", _for)
+        else:
+            el.set("data-dfn-for", _for)
 
 
 def addImplicitAlgorithms(doc: "t.SpecType"):
@@ -380,7 +377,8 @@ def fixIntraDocumentReferences(doc: "t.SpecType"):
     ids = {el.get("id"): el for el in h.findAll("[id]", doc)}
     headingIDs = {el.get("id"): el for el in h.findAll("[id].heading", doc)}
     for el in h.findAll("a[href^='#']:not([href='#']):not(.self-link):not([data-link-type])", doc):
-        targetID = parse.unquote(el.get("href")[1:])
+        href = t.cast(str, el.get("href"))
+        targetID = parse.unquote(href[1:])
         if el.get("data-section") is not None and targetID not in headingIDs:
             m.die(f"Couldn't find target document section {targetID}:\n{h.outerHTML(el)}", el=el)
             continue
@@ -405,20 +403,20 @@ def fixIntraDocumentReferences(doc: "t.SpecType"):
 
 def fixInterDocumentReferences(doc: "t.SpecType"):
     for el in h.findAll("[spec-section]", doc):
-        spec = el.get("data-link-spec").lower()
-        section = el.get("spec-section", "")
-        if spec is None:
+        if el.get("data-link-spec") is None:
             m.die(
                 f"Spec-section autolink doesn't have a 'spec' attribute:\n{h.outerHTML(el)}",
                 el=el,
             )
             continue
-        if section is None:
+        spec = el.get("data-link-spec", "").lower()
+        if el.get("spec-section") is None:
             m.die(
                 f"Spec-section autolink doesn't have a 'spec-section' attribute:\n{h.outerHTML(el)}",
                 el=el,
             )
             continue
+        section = el.get("spec-section", "")
         if spec in doc.refs.specs:
             # Bikeshed recognizes the spec
             fillInterDocumentReferenceFromShepherd(doc, el, spec, section)
@@ -883,8 +881,8 @@ def processAutolinks(doc: "t.SpecType"):
             continue
 
         classifyLink(el)
-        linkType = el.get("data-link-type")
-        linkText = el.get("data-lt")
+        linkType = t.cast(str, el.get("data-link-type"))
+        linkText = t.cast(str, el.get("data-lt"))
 
         # Properties and descriptors are often written like 'foo-*'. Just ignore these.
         if linkType in ("property", "descriptor", "propdesc") and "*" in linkText:
@@ -909,6 +907,10 @@ def processAutolinks(doc: "t.SpecType"):
             m.die(f"Unknown link status '{status}' on {h.outerHTML(el)}")
             continue
 
+        # Some links are okay to fail, and so should do so silently.
+        okayToFail = el.get("data-okay-to-fail") is not None
+        ignorable = linkText.lower() in doc.md.ignoredTerms
+
         ref = doc.refs.getRef(
             linkType,
             linkText,
@@ -918,7 +920,7 @@ def processAutolinks(doc: "t.SpecType"):
             linkForHint=el.get("data-link-for-hint"),
             explicitFor=doc.md.assumeExplicitFor,
             el=el,
-            error=(linkText.lower() not in doc.md.ignoredTerms),
+            error=not okayToFail and not ignorable,
         )
         # Capture the reference (and ensure we add a biblio entry) if it
         # points to an external specification. We check the spec name here
@@ -1003,7 +1005,7 @@ def removeMultipleLinks(doc: "t.SpecType"):
         if h.hasAncestor(el, lambda x: x.tag in ["pre", "xmp"]):
             # Don't strip out repeated links from opaque elements
             continue
-        paras[h.parentElement(el)][el.get("href")].append(el)
+        paras[h.parentElement(el)][el.get("href", "")].append(el)
     for linkGroups in paras.values():
         for _, links in linkGroups.items():
             if len(links) > 1:
@@ -1164,10 +1166,10 @@ def cleanupHTML(doc: "t.SpecType"):
         # when a markdown-generated dl has a div parent and dl grandparent
         # and remove it.
         if (
-            el.tag == "dl"
+            h.tagName(el) == "dl"
             and el.get("data-md") is not None
-            and h.parentElement(el).tag == "div"
-            and h.parentElement(h.parentElement(el)).tag == "dl"
+            and h.tagName(h.parentElement(el)) == "div"
+            and h.tagName(h.parentElement(el, 2)) == "dl"
         ):
             # Also featureless and can be safely thrown away
             # with its children merged into the parent div
@@ -1306,7 +1308,8 @@ def cleanupHTML(doc: "t.SpecType"):
             head.append(el)
     for el in styleScoped:
         parent = h.parentElement(el)
-        h.prependChild(parent, el)
+        if parent is not None:
+            h.prependChild(parent, el)
     for el in nestedLists:
         h.replaceWithContents(el)
     for el in flattenEls:
@@ -1387,20 +1390,27 @@ def formatArgumentdefTables(doc: "t.SpecType"):
         if not method:
             m.die(f"Can't find method '{forMethod}'.", el=table)
             continue
-        for tr in h.findAll("tbody > tr", table):
-            tds = h.findAll("td", tr)
-            argName = h.textContent(tds[0]).strip()
+        for i, tr in enumerate(h.findAll("tbody > tr", table)):
+            try:
+                argCell, typeCell, nullCell, optCell, _ = h.findAll("td", tr)
+            except ValueError:
+                m.die(
+                    f"In the argumentdef table for '{method.full_name}', row {i} is misformatted, with {len(h.findAll('td', tr))} cells instead of 5.",
+                    el=table,
+                )
+                continue
+            argName = h.textContent(argCell).strip()
             arg = method.find_argument(argName)
             if arg:
-                h.appendChild(tds[1], str(arg.type))
+                h.appendChild(typeCell, idl.nodesFromType(arg.type))
                 if str(arg.type).strip().endswith("?"):
-                    h.appendChild(tds[2], h.E.span({"class": "yes"}, "✔"))
+                    h.appendChild(nullCell, h.E.span({"class": "yes"}, "✔"))
                 else:
-                    h.appendChild(tds[2], h.E.span({"class": "no"}, "✘"))
+                    h.appendChild(nullCell, h.E.span({"class": "no"}, "✘"))
                 if arg.optional:
-                    h.appendChild(tds[3], h.E.span({"class": "yes"}, "✔"))
+                    h.appendChild(optCell, h.E.span({"class": "yes"}, "✔"))
                 else:
-                    h.appendChild(tds[3], h.E.span({"class": "no"}, "✘"))
+                    h.appendChild(optCell, h.E.span({"class": "no"}, "✘"))
             else:
                 m.die(
                     f"Can't find the '{argName}' argument of method '{method.full_name}' in the argumentdef block.",
@@ -1420,7 +1430,7 @@ def inlineRemoteIssues(doc: "t.SpecType"):
     inlineIssues = []
     GitHubIssue = namedtuple("GitHubIssue", ["user", "repo", "num", "el"])
     for el in h.findAll("[data-inline-github]", doc):
-        user, repo, num = el.get("data-inline-github").split()
+        user, repo, num = el.get("data-inline-github", "").split()
         inlineIssues.append(GitHubIssue(user, repo, num, el=el))
         h.removeAttr(el, "data-inline-github")
     if not inlineIssues:
@@ -1541,7 +1551,7 @@ def addNoteHeaders(doc: "t.SpecType"):
             preText = "EXAMPLE: "
         else:
             preText = ""
-        h.prependChild(el, h.E.div({"class": "marker"}, preText, *h.parseHTML(el.get("heading"))))
+        h.prependChild(el, h.E.div({"class": "marker"}, preText, *h.parseHTML(el.get("heading", ""))))
         h.removeAttr(el, "heading")
 
 
@@ -1583,7 +1593,7 @@ def addImageSize(doc: "t.SpecType"):
         elif src is not None and srcset is not None:
             continue
         elif src is None:
-            match = re.match(r"^[ \t\n]*([^ \t\n]+)[ \t\n]+(\d+)x[ \t\n]*$", srcset)
+            match = re.match(r"^[ \t\n]*([^ \t\n]+)[ \t\n]+(\d+)x[ \t\n]*$", srcset or "")
             if match is None:
                 m.die(
                     f"Couldn't parse 'srcset' attribute: \"{srcset}\"\n"
@@ -1594,7 +1604,8 @@ def addImageSize(doc: "t.SpecType"):
             else:
                 src = match.group(1)
                 el.set("src", src)
-                res = int(match.group(2))
+                res = int(match.group(2) or "1")
+        assert src is not None
         if not doc.inputSource.cheaplyExists(""):
             # If the input source can't tell whether a file cheaply exists,
             # PIL very likely can't use it either.
@@ -1633,3 +1644,18 @@ def addImageSize(doc: "t.SpecType"):
                 f"The height ({height}px) of this image is not a multiple of the declared resolution ({res}): {src}\nConsider fixing the image so its height is a multiple of the resolution, or setting its 'width' and 'height' attribute manually.",
                 el=el,
             )
+
+
+def processIDL(doc):
+    localDfns = set()
+    for pre in h.findAll("pre.idl, xmp.idl", doc):
+        if pre.get("data-no-idl") is not None:
+            continue
+        if not h.isNormative(pre, doc):
+            continue
+        localDfns.update(idl.markupIDLBlock(pre, doc))
+
+    dfns = h.findAll("pre.idl:not([data-no-idl]) dfn, xmp.idl:not([data-no-idl]) dfn", doc) + list(localDfns)
+    classifyDfns(doc, dfns)
+    h.fixupIDs(doc, dfns)
+    doc.refs.addLocalDfns(dfn for dfn in dfns if dfn.get("id") is not None)
